@@ -1,6 +1,6 @@
 package Import::Base;
 # ABSTRACT: Import a set of modules into the calling module
-$Import::Base::VERSION = '0.013';
+$Import::Base::VERSION = '0.014';
 use strict;
 use warnings;
 use mro ();
@@ -189,7 +189,7 @@ Import::Base - Import a set of modules into the calling module
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -356,7 +356,7 @@ instead of C<use>.
     our @IMPORT_MODULES = (
         'strict',
         'warnings',
-        feature => [qw( :5.20 )],
+        feature => [qw( :5.20 signatures )],
         '-warnings' => [qw( experimental::signatures )],
     );
 
@@ -490,7 +490,8 @@ Using C<package>, a subref could check or alter C<@ISA>, work with the object's
 metaclass (if you're using one), or export additional symbols not set up for
 export.
 
-Here's an example for applying a L<Moo::Role> when importing a bundle:
+Here's an example for applying a role (L<Moo::Role>, L<Role::Tiny>,
+L<Moose::Role>, and anything that uses C<with>) when importing a bundle:
 
     package My::Base;
     use base 'Import::Base';
@@ -500,7 +501,7 @@ Here's an example for applying a L<Moo::Role> when importing a bundle:
             # Plugins require the "My::Plugin" role
             sub {
                 my ( $bundles, $args ) = @_;
-                Moo::Role->apply_role_to_package( $args->{package}, 'My::Plugin' );
+                $args->{package}->can( 'with' )->( 'My::Plugin' );
                 return;
             },
         ],
@@ -700,13 +701,19 @@ doesn't do what you want, look at Import::Into to build your own.
 =item L<perl5|perl5>
 
 This module is very similar, and has a bunch of built-in bundles and features for
-quickly importing Perl feature sets.
+quickly importing Perl feature sets. It is also flexible, allowing you to specify
+your own module bundles.
 
 =item L<ToolSet|ToolSet>
 
-This is very similar, but does not appear to allow subclasses to remove imports from
-the list of things to be imported. By having the module list be a static array, we
-can modify it further in more levels of subclasses.
+ToolSet is very similar. Its API just uses package methods instead of package
+variables. It also allows for exporting symbols directly from the bundle,
+something Import::Base does not yet allow (patches welcome).
+
+=item L<sanity|sanity>
+
+Sanity is more consise, but not as flexible. If you don't need the wild
+flexibility of Import::Base or the above solutions, take a look.
 
 =item L<Toolkit|Toolkit>
 
